Enum t_rust_less_lib::api::SecretType
source · [−]pub enum SecretType {
Login,
Note,
Licence,
Wlan,
Password,
Other,
}Expand description
General type of a secret.
This only serves as a hint for an UI.
Variants
Login
Note
Licence
Wlan
Password
Other
Implementations
sourceimpl SecretType
impl SecretType
sourcepub fn password_properties(&self) -> &[&str]
pub fn password_properties(&self) -> &[&str]
Get the commonly used property name that may contain a password.
The values of these properties are automatically estimated for the strengths.
pub fn from_reader(api: SecretType) -> Self
pub fn to_builder(self) -> SecretType