Struct t_rust_less_lib::api::SecretEntry
source · [−]pub struct SecretEntry {
pub id: String,
pub name: String,
pub secret_type: SecretType,
pub tags: Vec<String>,
pub urls: Vec<String>,
pub timestamp: ZeroizeDateTime,
pub deleted: bool,
}Expand description
SecretEntry contains all the information of a secrets that should be indexed.
Even though a SecretEntry does no contain a password it is still supposed to be sensitive data.
See SecretVersion for further detail.
Fields
id: Stringname: Stringsecret_type: SecretTypeurls: Vec<String>timestamp: ZeroizeDateTimedeleted: boolImplementations
sourceimpl SecretEntry
impl SecretEntry
pub fn from_reader(reader: Reader<'_>) -> Result<Self>
pub fn to_builder(&self, builder: Builder<'_>)